/v1/virtualbox — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /v1/virtualbox

Contents

- /v1/virtualbox
  - POST /v1/virtualbox
    - Response status codes
    - Input
    - Output

## POST /v1/virtualbox

Create a new VirtualBox VM instance

### Response status codes

- 400: Invalid project UUID
- 201: Instance created
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_start_index |  | integer | adapter index from which to start using adapters
adapter_type |  | string | VirtualBox adapter type
adapters |  | integer | number of adapters
console |  | integer | console TCP port
enable_remote_console |  | boolean | enable the remote console
headless |  | boolean | headless mode
linked_clone | ✔ | boolean | either the VM is a linked clone or not
name | ✔ | string | VirtualBox VM instance name
project_id | ✔ | string | Project UUID
uuid |  | string | VirtualBox VM instance UUID
vbox_id |  | integer | VirtualBox VM instance ID (for project created before GNS3 1.3)
vmname | ✔ | string | VirtualBox VM name (in VirtualBox itself)

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_start_index |  | integer | adapter index from which to start using adapters
adapter_type |  | string | VirtualBox adapter type
adapters |  | integer | number of adapters
console |  | integer | console TCP port
enable_remote_console |  | boolean | enable the remote console
headless |  | boolean | headless mode
name | ✔ | string | VirtualBox VM instance name
project_id | ✔ | string | Project UUID
uuid | ✔ | string | VirtualBox VM instance UUID
vmname |  | string | VirtualBox VM name (in VirtualBox itself)

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »